View source: R/handler_rstudio.R
| handler_rstudio | R Documentation |
Progression Handler: Progress Reported in the RStudio Console
handler_rstudio(
intrusiveness = getOption("progressr.intrusiveness.gui", 1),
target = "gui",
title = function() format(Sys.time(), "Console %X"),
...
)
intrusiveness |
(numeric) A non-negative scalar on how intrusive (disruptive) the reporter to the user. |
target |
(character vector) Specifies where progression updates are rendered. |
title |
(character or a function) The "name" of the progressor, which is displayed in front of the progress bar. If a function, then the name is created dynamically by calling the function when the progressor is created. |
... |
Additional arguments passed to |
A function of class progression_handler that takes a
progression condition as its first and only argument.
This progression handler works only in the RStudio Console.
To use this handler by default whenever using the RStudio Console, add the following to your ‘~/.Rprofile’ startup file:
if (requireNamespace("progressr", quietly = TRUE)) {
if (Sys.getenv("RSTUDIO") == "1" && !nzchar(Sys.getenv("RSTUDIO_TERM"))) {
options(progressr.handlers = progressr::handler_rstudio)
}
}
if (requireNamespace("rstudioapi", quietly = TRUE) && rstudioapi::isAvailable()) {
handlers("rstudio")
with_progress({ y <- slow_sum_p(1:10) })
print(y)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.