View source: R/handler_progress.R
| handler_progress | R Documentation |
A progression handler for progress::progress_bar().
handler_progress(
format = NULL,
show_after = 0,
intrusiveness = getOption("progressr.intrusiveness.terminal", 1),
target = "terminal",
type = c("default", "steps", "percent", "time"),
...
)
format |
(character string) The format of the progress bar.
If |
show_after |
(numeric) Number of seconds to wait before displaying the progress bar. |
intrusiveness |
(numeric) A non-negative scalar on how intrusive (disruptive) the reporter to the user. |
target |
(character vector) Specifies where progression updates are rendered. |
type |
(character) The type of progress bar to display, which
controls the default |
... |
Additional arguments passed to |
A function of class progression_handler that takes a
progression condition as its first and only argument.
This progression handler requires the progress package.
Below are a few examples on how to use and customize this progress handler.
In all cases, we use handlers(global = TRUE).
library(progressr)
handlers("progress")
y <- slow_sum_p(1:25)
library(progressr) handlers(handler_progress(complete = "#")) y <- slow_sum_p(1:25)
library(progressr) handlers(handler_progress(type = "steps")) y <- slow_sum_p(1:25)
library(progressr) handlers(handler_progress(type = "percent")) y <- slow_sum_p(1:25)
library(progressr) handlers(handler_progress(type = "time")) y <- slow_sum_p(1:25)
library(progressr) handlers(handler_progress(format = ":spin [:bar] :percent :message")) y <- slow_sum_p(1:25)
library(progressr) handlers(handler_progress(format = ":percent [:bar] :eta :message")) y <- slow_sum_p(1:25)
if (requireNamespace("progress", quietly = TRUE)) {
handlers(handler_progress(format = ":spin [:bar] :percent :message"))
with_progress({ y <- slow_sum_p(1:10) })
print(y)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.