View source: R/handler_tutorial.R
| handler_tutorial | R Documentation |
A progressr handler useful for Futureverse tutorials
handler_tutorial(
...,
spec = c("progress", "cli"),
type = "time",
clear = FALSE
)
spec |
The progress handler to use. |
type |
Controls which predefined handler format string to use. |
clear |
(logical) If TRUE, any output, typically visual, produced by a reporter will be cleared/removed upon completion, if possible. |
... |
Arguments passed to the selected progress handler. |
The default is to use the progress package. Contrary to the cli package, the progress package has the capacity to display all progress updates, even when receiving progress updates at a high rate from, for example, parallel processing.
A function of class progression_handler that takes a
progression condition as its first and only argument.
# Display progress and keep the progress output when done
handlers("tutorial")
# Display progress and keep every progress reported
handlers("tutorial", "newline")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.