| slow_sum_p | R Documentation |
Slowly Calculate Sum or Square Roots of Elements
slow_sum_p(
x,
delay = getOption("progressr.demo.delay", 1),
stdout = getOption("progressr.demo.stdout", FALSE),
message = getOption("progressr.demo.message", TRUE),
sticky = getOption("progressr.demo.sticky", TRUE),
progress = getOption("progressr.demo.progress", TRUE)
)
slow_sum(
x,
delay = getOption("progressr.demo.delay", 1),
stdout = FALSE,
message = FALSE,
sticky = FALSE,
progress = FALSE
)
slow_sqrt_p(
x,
delay = getOption("progressr.demo.delay", 0.5),
stdout = getOption("progressr.demo.stdout", FALSE),
message = getOption("progressr.demo.message", TRUE),
sticky = getOption("progressr.demo.sticky", TRUE),
progress = getOption("progressr.demo.progress", TRUE)
)
slow_sqrt(
x,
delay = getOption("progressr.demo.delay", 0.5),
stdout = FALSE,
message = FALSE,
sticky = FALSE,
progress = FALSE
)
x |
Numeric vector to sum or calculate square roots for. |
delay |
Delay in seconds after each addition/calculation. |
stdout |
If TRUE, then a text is outputted to the standard output per element. |
message |
If TRUE, then a message is outputted per element. |
sticky |
If TRUE, then a "sticky" message is outputted every ten element. |
progress |
If TRUE, then a progressor is created, otherwise a void progressor that does nothing is used. |
The sum or square roots of all elements in x.
These functions signal progression conditions as they progress.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.